@@ -26,10 +26,12 @@ from uuid import uuid4
 
 
 class QHTTPProxyServer():
-    def __init__(self, ip=None, port=None, mocking=None, config=''):
+    def __init__(self, ip=None, port=None, mocking=None, username=None, password=None, config=''):
         self.auto_disabled = None
         self.ip = ip or '0.0.0.0'
         self.port = port or 8080
+        self.username = username or "test"
+        self.password = password or "test"
         self.mocking = mocking or ''
         self.process = None
         self.uuid = 'honeypotslogger' + '_' + __class__.__name__ + '_' + str(uuid4())[:8]
